PAWpySeed: pswf Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
pswf Struct Reference

`#include <utils.h>`

Collaboration diagram for pswf:
[legend]

## Public Attributes
double | encut
int | num_elems
| number of elements in the structure More...
int * | num_projs
| number of projectors for each element More...
int | num_sites
| number of sites in the structure More...
ppot_t * | pps
| list of ppot_t objects, one for each element More...
int * | G_bounds
| highest-frequency plane-waves in basis set (xmin, xmax, ymin, ymax, zmin, zmax) More...
kpoint_t ** | kpts
| list of kpoint_t objects for the structure More...
int | nspin
| 1 for non-spin-polarized/noncollinear, 2 for spin-polarized More...
int | nband
| number of bands More...
int | nwk
| number of kpoints More...
double * | lattice
| lattice (length 9, each row is a lattice, vector, row major) More...
double * | reclattice
| reciprocal lattice (with 2pi factor!), formatted like lattice More...
int * | fftg
| FFT grid dimensions. More...
int | is_ncl
| 1 if noncollinear, 0 otherwise More...
int | wp_num
| length==size of wave_projections in each band More...
int | num_aug_overlap_sites
| used for Projector operations More...
double * | dcoords
| used for Projector operations More...
double complex ** | overlaps
| used for Projector operations More...

## Member Data Documentation

double* pswf::dcoords

used for Projector operations

double pswf::encut

int* pswf::fftg

FFT grid dimensions.

int* pswf::G_bounds

highest-frequency plane-waves in basis set (xmin, xmax, ymin, ymax, zmin, zmax)

int pswf::is_ncl

1 if noncollinear, 0 otherwise

kpoint_t** pswf::kpts

list of kpoint_t objects for the structure

double* pswf::lattice

lattice (length 9, each row is a lattice, vector, row major)

int pswf::nband

number of bands

int pswf::nspin

1 for non-spin-polarized/noncollinear, 2 for spin-polarized

int pswf::num_aug_overlap_sites

used for Projector operations

int pswf::num_elems

number of elements in the structure

int* pswf::num_projs

number of projectors for each element

int pswf::num_sites

number of sites in the structure

int pswf::nwk

number of kpoints

double complex** pswf::overlaps

used for Projector operations

ppot_t* pswf::pps

list of ppot_t objects, one for each element

double* pswf::reclattice

reciprocal lattice (with 2pi factor!), formatted like lattice

int pswf::wp_num

length==size of wave_projections in each band

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h